DynamicTextField class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DynamicTextField
- Annotations
Constructors
-
DynamicTextField({required TextEditingController textDynamicController, required String title, String? titleList, String? hintSearch, required String hint, List<
SelectedItem> ? listItem, FieldType? fieldtype = FieldType.input, FormType? formType = FormType.basic, InputDecoration? inputDecoration, Color? backgroundColor, String? validator(String?)?, void onChanged(String)?, void onSaved(String?)?, AutovalidateMode? autovalidateMode, TextInputType? keyboardType, TextInputAction? textInputAction, int? maxLength, Key? key}) -
const
Properties
- autovalidateMode → AutovalidateMode?
-
final
- backgroundColor → Color?
-
final
- fieldtype → FieldType?
-
final
- formType → FormType?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String
-
final
- hintSearch → String?
-
final
- inputDecoration → InputDecoration?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
final
-
listItem
→ List<
SelectedItem> ? -
final
- maxLength → int?
-
final
- onChanged → void Function(String)?
-
final
- onSaved → void Function(String?)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textDynamicController → TextEditingController
-
final
- textInputAction → TextInputAction?
-
final
- title → String
-
final
- titleList → String?
-
final
- validator → String? Function(String?)?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → DynamicTextFieldState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited