DropDown class
Constructors
-
DropDown({Key? key, String? buttonText, String? titleList, Color? submitButtonColor, String? searchHintText, Color? searchBackgroundColor, Color? backgroundColor, required TextEditingController searchController, required List<
SelectedItem> dataList, dynamic selectedItem(String)?, dynamic selectedItem2(String)?, dynamic selectedItemMap(Map)?})
Properties
- backgroundColor → Color?
-
This will give the background color to the load list.
final
-
This gives the button text or it sets default text as 'click me'.
final
-
dataList
→ List<
SelectedItem> -
This will give the list of data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchBackgroundColor → Color?
-
This will give the background color to the search text filed.
final
- searchController → TextEditingController
-
This will give the default search controller to the search text field.
final
- searchHintText → String?
-
This will give the hint to the search text filed.
final
- selectedItem → dynamic Function(String)?
-
This will give the call back to the selected item (single) from list.
final
- selectedItem2 → dynamic Function(String)?
-
final
- selectedItemMap → dynamic Function(Map)?
-
final
- submitButtonColor → Color?
-
This will give the submit button background color.
final
- titleList → String?
-
This gives the bottom sheet title.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited